@@ -1,7 +1,5 @@
 nextPerm = function(mcObj){
-    bCont = TRUE
-    r = .C("next", set = as.integer(mcObj$set),
-                   b = as.integer(bCont), id = as.integer(mcObj$id))
+    r = nextPermC(mcObj$id)
 
     if(r$b){
         if(mcObj$mode == "integer"){
